{ config, pkgs, inputs, ... }:

{
  boot.supportedFilesystems = [ "ntfs" ];

  i18n.defaultLocale = "en_GB.UTF-8";
  i18n.extraLocaleSettings = {
    LC_ADDRESS = "en_GB.UTF-8";
    LC_IDENTIFICATION = "en_GB.UTF-8";
    LC_MEASUREMENT = "en_GB.UTF-8";
    LC_MONETARY = "en_GB.UTF-8";
    LC_NAME = "en_GB.UTF-8";
    LC_NUMERIC = "en_GB.UTF-8";
    LC_PAPER = "en_GB.UTF-8";
    LC_TELEPHONE = "en_GB.UTF-8";
    LC_TIME = "en_GB.UTF-8";
  };
  environment.variables.LC_ALL = "en_GB.UTF-8";

  time.timeZone = "Europe/London";

  users.groups.tmux.gid = 1000; # Used for tmux pairing
  systemd.tmpfiles.rules = [
    "d /var/tmux_share 2770 tsv tmux"
  ];

  users.users.tsv = {
    isNormalUser = true;
    extraGroups = [
      "wheel"
      "docker"
      "tmux"
    ];
    initialPassword = "password";
    openssh.authorizedKeys.keyFiles = [
      ../users/tsv/authorized_keys
    ];
  };

  nix.settings.trusted-users = [ "root" "tsv" ];

  nix = {
    extraOptions = "experimental-features = nix-command flakes";
    package = pkgs.nixFlakes;
    gc = {
      automatic = true;
      dates = "weekly";
      options  = "--delete-older-than 30d";
    };
  };

  hardware.bluetooth.enable = true;

  programs.gnupg.agent = {
    enable = true;
    enableSSHSupport = true;
    pinentryFlavor = "curses";
  };

  nixpkgs.config.allowUnfree = true;

  services.openssh = {
    enable = true;
    settings.PasswordAuthentication = false;
  };

  system.stateVersion = "22.11"; # Don't change this
}

